.. sospice documentation master file, created by
   sphinx-quickstart on Wed Apr 26 11:55:22 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

sospice documentation
=====================

`SPICE <https://spice.ias.u-psud.fr/>`__ is an extreme-UV imaging
spectrometer on board the `Solar
Orbiter <http://sci.esa.int/solar-orbiter/>`__ mission.

``sospice`` is intended to be a simple way of accessing all necessary
functionalities required for day-to-day SPICE data analysis. This
package is in its early stages of development. Please see the
`issues <https://github.com/solo-spice/sospice/issues>`__ to see how you
can contribute.

A generic SPICE data analysis user’s manual (including Python and IDL
tips) is available `on the IAS
wiki <https://spice-wiki.ias.u-psud.fr/doku.php/data:data_analysis_manual>`__.


.. toctree::
   :maxdepth: 2

   getting_started
   citation
   api
   develop
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
